@@ -18,6 +18,7 @@
 #include "netpbm/pm_c_util.h"
 #include "netpbm/nstring.h"
 #include "rle.h"
+#include "rle_config.h"
 
 
 
@@ -52,7 +53,7 @@ my_popen(const char * const cmd,
         return NULL;
     }
 
-    if ( pipe(pipefd) < 0 )
+    if (pm_pipe(pipefd) < 0 )
         return NULL;
     
     /* Flush known files. */
@@ -234,7 +235,7 @@ dealWithSubprocess(const char *  const file_name,
  *  will return a pointer to stdin or stdout depending on the mode.
  *    If the user specifies a non-null file name and an I/O error occurs
  *  when trying to open the file, rle_open_f will terminate execution with
- *  an appropiate error message.
+ *  an appropriate error message.
  *
  *  parameters
  *   input:
